@@ -53,7 +53,7 @@ IpMessengerAgentImpl::CryptoInit()
 	RsaMax = RSA_generate_key( RSA_KEY_LENGTH_MAXIMUM, ENCRYPT_PRIME, NULL, NULL );
 	if ( RsaMax == NULL ) {
 		char errbuf[ERR_BUF_SIZE];
-		printf("in encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
+		printf("in Encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
 	} else {
 		encryptionCapacity |= IPMSG_RSA_2048;
 		printf("encryption extention enabled.(RSA2048)\n");fflush(stdout);
@@ -64,7 +64,7 @@ IpMessengerAgentImpl::CryptoInit()
 	RsaMid = RSA_generate_key( RSA_KEY_LENGTH_MIDIUM, ENCRYPT_PRIME, NULL, NULL );
 	if ( RsaMid == NULL ) {
 		char errbuf[ERR_BUF_SIZE];
-		printf("in encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
+		printf("in Encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
 	} else {
 		encryptionCapacity |= IPMSG_RSA_1024;
 		printf("encryption extention enabled.(RSA1024)\n");fflush(stdout);
@@ -75,7 +75,7 @@ IpMessengerAgentImpl::CryptoInit()
 	RsaMin = RSA_generate_key( RSA_KEY_LENGTH_MINIMUM, ENCRYPT_PRIME, NULL, NULL );
 	if ( RsaMin == NULL ) {
 		char errbuf[ERR_BUF_SIZE];
-		printf("in encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
+		printf("in Encrypt: err=%s\n", ERR_error_string( ERR_get_error(), errbuf ) );fflush(stdout);
 	} else {
 		encryptionCapacity |= IPMSG_RSA_512;
 		printf("encryption extention enabled.(RSA512)\n");fflush(stdout);
@@ -134,11 +134,11 @@ IpMessengerAgentImpl::CryptoEnd()
  * @param optBufLen ѥåȥץΥХåեθߤͭǡĹ
  * @param enc_optBufLen Ź沽ѤΥѥåȥץΥХåեͭǡĹΥɥ쥹
  * @param opt_size ѥåȥץΥХåեΥ
- * @retval true:Ź沽OKfalse:Ź沽NG
- * Υ᥽åɤϥåɥդǤʤ
+ * @retval true:沽
+ * @retval false:沽
  */
 bool
-IpMessengerAgentImpl::EncryptMsg( HostListItem host, unsigned char *optBuf, int optBufLen, int *enc_optBufLen, int opt_size )
+IpMessengerAgentImpl::EncryptMsg( const HostListItem& host, unsigned char *optBuf, int optBufLen, int *enc_optBufLen, int opt_size )
 {
 #ifdef HAVE_OPENSSL
 	unsigned long pubKeyMethod = 0UL;
@@ -414,11 +414,11 @@ IpMessengerAgentImpl::EncryptMsg( HostListItem host, unsigned char *optBuf, int
 /**
  * å沽
  * @param packet ѥåȥ֥ȡʻȡ
- * @retval true:沽OKfalse:沽NG
- * Υ᥽åɤϥåɥդǤʤ
+ * @retval true:沽
+ * @retval false:沽
  */
 bool
-IpMessengerAgentImpl::DecryptMsg( Packet &packet )
+IpMessengerAgentImpl::DecryptMsg( const Packet &packet, string& msg )
 {
 #ifdef HAVE_OPENSSL
 	EVP_CIPHER_CTX ctx;
@@ -746,7 +746,7 @@ IpMessengerAgentImpl::DecryptMsg( Packet &packet )
 		memcpy( &optBuf[tmp_len+1], file_info, file_info_len );
 		tmp_len += ( file_info_len + 1 );
 	}
-	packet.setOption( string( (char *)optBuf, tmp_len ) );
+	msg = string( (char *)optBuf, tmp_len );
 	IpMsgPrintBuf( "optBuf(2):", (char *)optBuf, tmp_len );
 	free( optBuf );
 	free( file_info );
@@ -756,6 +756,11 @@ IpMessengerAgentImpl::DecryptMsg( Packet &packet )
 #endif	//HAVE_OPENSSL
 }
 
+/**
+ * ŬRSA֥Ȥ򤷤ֵѤ롣
+ * @param cap ʬΰŹ沽ǽϤ򼨤ե饰
+ * @retval Ź沽˻ѤRSA֥ȡ
+ */
 RSA *
 IpMessengerAgentImpl::GetOptimizedRsa( unsigned long cap ){
 	RSA *rsa = NULL;
