@@ -16,6 +16,137 @@ using namespace std;
 
 #define HOST_LIST_SEND_MAX_AT_ONCE	100
 
+/**
+ * 󥹥ȥ饯
+ * <ul>
+ * <li>ۥȥꥹȤå뤿Υߥ塼ƥå</li>
+ * </ul>
+ */
+HostList::HostList()
+{
+	IpMsgMutexInit( "HostList::HostList()", &hostListMutex, NULL );
+}
+
+/**
+ * ԡ󥹥ȥ饯
+ * <ul>
+ * <li>ۥȥꥹȤå뤿Υߥ塼ƥå</li>
+ * </ul>
+ * @param other ԡΥ֥
+ */
+HostList::HostList( const HostList& other )
+{
+	IpMsgMutexInit( "HostList::HostList(HostList&)", &hostListMutex, NULL );
+	Lock( "HostList::HostList(HostList&)" );
+	CopyFrom( other );
+	Unlock( "HostList::HostList(HostList&)" );
+}
+
+/**
+ * ǥȥ饯
+ * <ul>
+ * <li>ۥȥꥹȤå뤿Υߥ塼ƥå˴</li>
+ * </ul>
+ */
+HostList::~HostList()
+{
+	IpMsgMutexDestroy( "HostList::~HostList()", &hostListMutex );
+}
+
+/**
+ * 黻ҡ
+ * <ul>
+ * <li>ۥȥꥹȤå뤿Υߥ塼ƥå</li>
+ * </ul>
+ * @param other ԡΥ֥
+ * @retval ֥ȤΥ󥹥
+ */
+HostList&
+HostList::operator=( const HostList& other )
+{
+	IpMsgMutexInit( "HostList::operator=(HostList&)", &hostListMutex, NULL );
+	Lock( "HostList::operator=(HostList&)" );
+	CopyFrom( other );
+	Unlock( "HostList::operator=(HostList&)" );
+	return *this;
+}
+
+/**
+ * ԡ᥽åɡ
+ * @param other ԡΥ֥
+ */
+void
+HostList::CopyFrom( const HostList& other )
+{
+	items = other.items;
+}
+
+/**
+ * ۥȥꥹȤå
+ * @param pos åƤ֤򼨤ʸ
+ */
+void
+HostList::Lock( const char *pos ) const
+{
+	IpMsgMutexLock( pos, const_cast< pthread_mutex_t* >( &hostListMutex ) );
+}
+
+/**
+ * ۥȥꥹȤ򥢥å
+ * @param pos åƤ֤򼨤ʸ
+ */
+void
+HostList::Unlock( const char *pos ) const
+{
+	IpMsgMutexUnlock( pos, const_cast< pthread_mutex_t * >( &hostListMutex ) );
+}
+
+/**
+ * ۥȥꥹȤƬ򼨤ƥ졼֤
+ * @retval ۥȥꥹȤƬ򼨤ƥ졼
+ */
+inline
+vector<HostListItem>::iterator
+HostList::begin()
+{
+	return items.begin();
+}
+
+/**
+ * ۥȥꥹȤܣ򼨤ƥ졼֤
+ * @retval ۥȥꥹȤܣ򼨤ƥ졼
+ */
+inline
+vector<HostListItem>::iterator
+HostList::end()
+{
+	return items.end();
+}
+
+/**
+ * ۥȥꥹȤθĿ֤
+ * @retval ۥȥꥹȤθĿ
+ */
+int
+HostList::size() const
+{
+	Lock( "HostList::size()" );
+	int ret = items.size();
+	Unlock( "HostList::size()" );
+	return ret;
+}
+
+/**
+ * ۥȥꥹȤ򥯥ꥢ롣
+ */
+void
+HostList::clear()
+{
+	Lock( "HostList::clear()" );
+	items.clear();
+	Unlock( "HostList::clear()" );
+}
+
 /**
  * С䤤碌Ԥ
  */
@@ -38,10 +169,11 @@ HostListItem::QueryAbsenceInfo()
 
 /**
  * IPɥ쥹򸵤˥ۥȤɤ롣
- * @retval true:ۥȡfalse:ۥȤǤϤʤ
+ * @retval true:ۥ
+ * @retval false:ۥȤǤϤʤ
  */
 bool
-HostListItem::IsLocalHost()
+HostListItem::IsLocalHost() const
 {
 	IpMessengerAgentImpl *agent = IpMessengerAgentImpl::GetInstance();
 	vector<NetworkInterface> nics = agent->NICs;
@@ -64,8 +196,9 @@ HostListItem::IsLocalHost()
  * @param host ۥȾ
  */
 void
-HostList::AddHost( HostListItem host )
+HostList::AddHost( const HostListItem& host )
 {
+	Lock( "HostList::AddHost()" );
 	bool is_found = false;
 
 	IpMessengerAgentImpl *agent = IpMessengerAgentImpl::GetInstance();
@@ -75,7 +208,18 @@ HostList::AddHost( HostListItem host )
 #if defined(INFO) || !defined(NDEBUG)
 		printf("AddHost HOST CHECK IpAddress=%s addr=%s\n", host.IpAddress().c_str(), nics[i].IpAddress().c_str() );fflush(stdout);
 #endif
-		if ( host.IpAddress() == nics[i].IpAddress() ){
+		if ( host.IpAddress() == nics[i].IpAddress() ) {
+			Unlock( "HostList::AddHost()" );
+			return;
+		}
+	}
+	for( unsigned int i = 0; i < nics.size(); i++ ){
+#if defined(INFO) || !defined(NDEBUG)
+		printf("AddHost HOST CHECK IpAddress=%s addr=%s\n", host.IpAddress().c_str(), nics[i].IpAddress().c_str() );fflush(stdout);
+#endif
+		if ( host.IpAddress() == nics[i].NetworkAddress() ||
+			 host.IpAddress() == nics[i].BroadcastAddress() ){
+			Unlock( "HostList::AddHost()" );
 			return;
 		}
 	}
@@ -87,56 +231,73 @@ HostList::AddHost( HostListItem host )
 #if defined(INFO) || !defined(NDEBUG)
 		printf("IGNORE HOST.Because host IpAddress local loopback.\n" );fflush(stdout);
 #endif
+		Unlock( "HostList::AddHost()" );
 		return;
 	}
 	if ( host.IpAddress() == nics[0].IpAddress() && host.HostName() != localhostName ){
+		Unlock( "HostList::AddHost()" );
 		return;
 	}
 	for( unsigned int i = 0; i < items.size(); i++ ){
-		if ( host.Equals( items.at( i ) ) ) {
+		HostListItem tmpHost = items.at( i );
+		if ( tmpHost.Equals( host ) ) {
 			is_found = true;
 			break;
 		}
 	}
 	if ( !is_found ) {
+#if defined(INFO) || !defined(NDEBUG)
+		printf("AddHost Nickname=%s\n", host.Nickname().c_str() );fflush(stdout);
+		printf("AddHost GroupName=%s\n", host.GroupName().c_str() );fflush(stdout);
+#endif
 		items.push_back( host );
 	}
 	if ( agent->GetSortHostListComparator() != NULL ){
-		qsort( agent->GetSortHostListComparator(), 0, items.size() - 1 );
+		if ( items.size() > 0 ) {
+			qsort( agent->GetSortHostListComparator(), 0, items.size() - 1 );
+		}
 	}
+	Unlock( "HostList::AddHost()" );
 }
 
 /**
  * ۥȾۥȥꥹȤ롣
- * @param ۥȾΥƥ졼
+ * @param it ۥȾΥƥ졼
  */
 void
 HostList::Delete( vector<HostListItem>::iterator &it )
 {
+	Lock( "HostList::Delete()" );
 	items.erase( it );
+	Unlock( "HostList::Delete()" );
 }
 /**
  * ۥȾۥȥꥹȤ롣
- * @param ۥ̾
+ * @param hostname ۥ̾
  */
 void
 HostList::DeleteHost( string hostname )
 {
+	Lock( "HostList::DeleteHost()" );
 	for( vector<HostListItem>::iterator ix = items.begin(); ix < items.end(); ix++ ){
 		if ( ix->HostName() == hostname ) {
 			items.erase( ix );
 			break;
 		}
 	}
+	Unlock( "HostList::DeleteHost()" );
 }
 
 /**
  * ۥȥꥹʸ롣
  * @param start ϰ
+ * @param addr Υɥ쥹
+ * @retval ۥȥꥹʸ
  */
 string
-HostList::ToString( int start )
+HostList::ToString( int start, const struct sockaddr_in *addr )
 {
+	Lock( "HostList::ToString" );
 	char buf[MAX_UDPBUF];
 	string ret;
 	unsigned int maxLength= IpMessengerAgentImpl::GetInstance()->GetMaxOptionBufferSize();
@@ -145,14 +306,36 @@ HostList::ToString( int start )
 	int hostCount = 0;
 	for( unsigned int i = start ; i < items.size(); i++ ){
 		HostListItem item = items.at( i );
-		sprintf( buf, "%s\a%s\a%ld\a%s\a%d\a%s\a%s\a",
-						item.UserName() == "" ? "\b" : item.UserName().c_str(),
-						item.HostName() == "" ? "\b" : item.HostName().c_str(),
-						item.CommandNo(),
-						item.IpAddress() == "" ? "\b" : item.IpAddress().c_str(),
-						htons( item.PortNo() ),
-						item.Nickname() == "" ? "\b" : item.Nickname().c_str(),
-						item.GroupName() == "" ? "\b" : item.GroupName().c_str() );
+		//ʬIPɥ쥹֤¾ΥͥåȥΥɥ쥹äƤˡ
+		//Υ󥿡եΥɥ쥹֤
+		if ( item.IsLocalHost() ) {
+			IpMessengerAgentImpl *agent = IpMessengerAgentImpl::GetInstance();
+			vector<NetworkInterface> nics = agent->NICs;
+			string localaddr = nics[0].IpAddress();
+			for( unsigned int i = 0; i < nics.size(); i++ ){
+				if ( nics[i].NativeNetworkAddress() == (in_addr_t)( addr->sin_addr.s_addr & nics[i].NativeNetMask() ) ){
+					localaddr = nics[i].IpAddress();
+					break;
+				}
+			}
+			sprintf( buf, "%s\a%s\a%ld\a%s\a%d\a%s\a%s\a",
+							item.UserName() == "" ? "\b" : item.UserName().c_str(),
+							item.HostName() == "" ? "\b" : item.HostName().c_str(),
+							item.CommandNo(),
+							localaddr == "" ? "\b" : localaddr.c_str(),
+							htons( item.PortNo() ),
+							item.Nickname() == "" ? "\b" : item.Nickname().c_str(),
+							item.GroupName() == "" ? "\b" : item.GroupName().c_str() );
+		} else {
+			sprintf( buf, "%s\a%s\a%ld\a%s\a%d\a%s\a%s\a",
+							item.UserName() == "" ? "\b" : item.UserName().c_str(),
+							item.HostName() == "" ? "\b" : item.HostName().c_str(),
+							item.CommandNo(),
+							item.IpAddress() == "" ? "\b" : item.IpAddress().c_str(),
+							htons( item.PortNo() ),
+							item.Nickname() == "" ? "\b" : item.Nickname().c_str(),
+							item.GroupName() == "" ? "\b" : item.GroupName().c_str() );
+		}
 		if ( ret.length() >= maxLength ){
 			break;
 		}
@@ -161,6 +344,7 @@ HostList::ToString( int start )
 	}
 	snprintf( buf, sizeof( buf ), "%-5d\a%-5d\a", start , hostCount );
 	ret = buf + ret;
+	Unlock( "HostList::ToString" );
 	return ret;
 }
 
@@ -170,7 +354,7 @@ HostList::ToString( int start )
  * @retval ۥȥꥹȥƥ
  */
 HostListItem
-HostList::CreateHostListItemFromPacket( Packet packet )
+HostList::CreateHostListItemFromPacket( const Packet& packet )
 {
 	HostListItem ret;
 	ret.setHostName( packet.HostName() );
@@ -179,9 +363,9 @@ HostList::CreateHostListItemFromPacket( Packet packet )
 	char tmp[100];
 	ret.setIpAddress( inet_ntoa_r( packet.Addr().sin_addr.s_addr, tmp, sizeof( tmp ) ) );
 #if defined(INFO) || !defined(NDEBUG)
-	printf( "CreateHostListItemFromPacket port %d\n", packet.Addr().sin_port );fflush(stdout);
+	printf( "CreateHostListItemFromPacket port %d\n", ntohs( packet.Addr().sin_port ) );fflush(stdout);
 #endif
-	ret.setPortNo( packet.Addr().sin_port );
+	ret.setPortNo( ntohs( packet.Addr().sin_port ) );
 	unsigned int loc = packet.Option().find_first_of( '\0' );
 	if ( loc == string::npos ) {
 		ret.setNickname( packet.Option() );
@@ -197,75 +381,80 @@ HostList::CreateHostListItemFromPacket( Packet packet )
  * ۥȥꥹȤۥ̾ǸHostListItemֵѤ롣
  * @param hostName ۥ̾
  * @retval HostListItem
- * Υ᥽åɤϥåɥդǤʤ
  */
 vector<HostListItem>::iterator
 HostList::FindHostByHostName( string hostName )
 {
+	Lock( "HostList::FindHostByHostName()" );
+	vector<HostListItem>::iterator ret = end();
 	for( vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
 		if ( ix->HostName() == hostName ) {
-			return ix;
+			ret = ix;
+			break;
 		}
 	}
-	return end();
+	Unlock( "HostList::FindHostByHostName()" );
+	return ret;
 }
 
 /**
  * ۥȥꥹȤIPɥ쥹ǸHostListItemֵѤ롣
  * @param addr IPɥ쥹ʸ
  * @retval HostListItem
- * Υ᥽åɤϥåɥդǤʤ
  */
 vector<HostListItem>::iterator
 HostList::FindHostByAddress( string addr )
 {
+	Lock( "HostList::FindHostByAddress()" );
+	vector<HostListItem>::iterator ret = end();
 	for( vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
 #if defined(DEBUG)
-printf("HOST CHECK IpAddress=%s addr=%s\n", ix->IpAddress().c_str(), addr.c_str() );fflush(stdout);
+		printf("HOST CHECK IpAddress=%s addr=%s\n", ix->IpAddress().c_str(), addr.c_str() );fflush(stdout);
 #endif
 		if ( ix->IpAddress() == addr ) {
 #if defined(DEBUG)
-printf("\n");fflush(stdout);
-printf("HOST FOUND!!!\n");fflush(stdout);
-printf("\n");fflush(stdout);
+			printf("HOST FOUND!!!\n");fflush(stdout);
 #endif
-			return ix;
+			ret = ix;
+			break;
 		}
 	}
 #if defined(DEBUG)
-printf("\n");fflush(stdout);
-printf("HOST NOT FOUND!!!\n");fflush(stdout);
-printf("\n");fflush(stdout);
+	printf("HOST NOT FOUND!!!\n");fflush(stdout);
 #endif
-	return end();
+	Unlock( "HostList::FindHostByAddress()" );
+	return ret;
 }
 
 /**
  * ۥȤեźդ򥵥ݡȤƤ뤫
- * @retval ݡȡtrueݡȤʤfalse
+ * @retval true:ݡ
+ * @retval false:ݡȤʤ
  */
 bool
-HostListItem::IsFileAttachSupport()
+HostListItem::IsFileAttachSupport() const
 {
 	return CommandNo() & IPMSG_FILEATTACHOPT;
 }
 
 /**
  * ۥȤŹ򥵥ݡȤƤ뤫
- * @retval ݡȡtrueݡȤʤfalse
+ * @retval true:ݡ
+ * @retval false:ݡȤʤ
  */
 bool
-HostListItem::IsEncryptSupport()
+HostListItem::IsEncryptSupport() const
 {
 	return CommandNo() & IPMSG_ENCRYPTOPT;
 }
 
 /**
  * ۥȤԺߤ
- * @retval ԺߡtrueԺߤǤʤfalse
+ * @retval true:Ժ
+ * @retval false:ԺߤǤʤ
  */
 bool
-HostListItem::IsAbsence()
+HostListItem::IsAbsence() const
 {
 	return CommandNo() & IPMSG_ABSENCEOPT;
 }
@@ -273,15 +462,23 @@ HostListItem::IsAbsence()
 /**
  * ۥȥꥹȥƥ४֥ȤʬȰפ뤫֤
  * @param item ۥȥꥹȥƥ
- * @retval סtrueפʤfalse
+ * @retval true:
+ * @retval false:פʤ
  */
 bool
-HostListItem::Equals( HostListItem item )
+HostListItem::Equals( const HostListItem& item ) const
 {
 	return	Compare( item ) == 0;
 }
+/**
+ * ӡ
+ * @param item ۥȾ1
+ * @retval -n:*this礭
+ * @retval 0:item*this
+ * @retval +n:item礭
+ */
 int
-HostListItem::Compare( HostListItem item )
+HostListItem::Compare( const HostListItem& item ) const
 {
 //	if ( item.UserName()  == UserName() &&
 //		 item.HostName()  == HostName() &&
@@ -318,8 +515,8 @@ HostList::qsort( HostListComparator *comparator, int left, int right )
 	//ϰϤγϡλ
 	int i = left, j = right;
 #if defined(INFO) || !defined(NDEBUG)
-printf("ADDRESS LEFT(%d)  =IpAddress=%s\n", left, (items.begin() + left)->IpAddress().c_str() );fflush(stdout);
-printf("ADDRESS RIGHT(%d) =IpAddress=%s\n", right, (items.begin() + right)->IpAddress().c_str() );fflush(stdout);
+	printf("ADDRESS LEFT(%d)  =IpAddress=%s\n", left, (items.begin() + left)->IpAddress().c_str() );fflush(stdout);
+	printf("ADDRESS RIGHT(%d) =IpAddress=%s\n", right, (items.begin() + right)->IpAddress().c_str() );fflush(stdout);
 #endif
 	//
 	vector<HostListItem>::iterator pivot = items.begin() + ( ( left + right ) / 2 );
@@ -329,13 +526,13 @@ printf("ADDRESS RIGHT(%d) =IpAddress=%s\n", right, (items.begin() + right)->IpAd
 		while( comparator->compare( pivot, items.begin() + j ) < 0 ) j--;
 		if ( i >= j ) break;
 #if defined(INFO) || !defined(NDEBUG)
-printf("SWAP BEFORE I(%d)  =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
-printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
+			printf("SWAP BEFORE I(%d)  =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
+			printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
 #endif
 		iter_swap( items.begin() + i, items.begin() + j );
 #if defined(INFO) || !defined(NDEBUG)
-printf("SWAP BEFORE I(%d) =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
-printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
+		printf("SWAP BEFORE I(%d) =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
+		printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
 #endif
 		i++;
 		j--;
@@ -355,6 +552,8 @@ printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().
 void
 HostList::sort( HostListComparator *comparator )
 {
-	qsort( comparator, 0, items.size() - 1 );
+	if ( items.size() > 0 ) {
+		qsort( comparator, 0, items.size() - 1 );
+	}
 }
 //end of source
