@@ -40,8 +40,11 @@ using namespace std;
  * -------------------------------------------------------------------
  * Ÿޤ
  **/
-#define IPMSG_READONLY_PROPERTY(t, name ) private: t _##name; \
-								public: t name() const { return _##name; };
+#define IPMSG_READONLY_PROPERTY(t, name ) \
+									private: \
+										t _##name; \
+									public: \
+										inline t name() const { return _##name; };
 
 /**
  * ɤ߽ξѥץѥƥ
@@ -53,9 +56,11 @@ using namespace std;
  * -------------------------------------------------------------------
  * Ÿޤ
  **/
-#define IPMSG_PROPERTY(t, name ) private: t _##name; \
-								public: t name() const { return _##name; };\
-								void set##name( const t val ){ _##name = val; };
+#define IPMSG_PROPERTY(t, name )	private: \
+										t _##name; \
+									public: \
+										inline t name() const { return _##name; }; \
+										inline void set##name( const t val ){ _##name = val; };
 
 /**
  * ɤ߽ξѥץѥƥ()
@@ -67,10 +72,15 @@ using namespace std;
  * -------------------------------------------------------------------
  * Ÿޤ
  **/
-#define IPMSG_PROPERTY_REF(t, name ) private: t _##name; \
-									public: t& name() { return _##name; };\
-									void set##name( t& val ){ _##name = val; };
-
+#define IPMSG_PROPERTY_REF(t, name )	\
+									private: \
+										t _##name; \
+									public: \
+										inline t& name() { return _##name; }; \
+										inline void set##name( const t& val ){ _##name = val; };
+/**
+ * ѥåȥ饹
+ **/
 class Packet{
 	public:
 		IPMSG_PROPERTY( unsigned long, VersionNo );
@@ -85,19 +95,35 @@ class Packet{
 		IPMSG_PROPERTY( int, TcpSocket );
 };
 
+/**
+ * ͥåȥ󥿡ե饹
+ **/
 class NetworkInterface {
 	public:
 		IPMSG_PROPERTY( string, DeviceName );
 		IPMSG_PROPERTY( string, IpAddress );
+		IPMSG_PROPERTY( string, NetMask );
+		IPMSG_PROPERTY( string, NetworkAddress );
+		IPMSG_PROPERTY( string, BroadcastAddress );
+		IPMSG_PROPERTY( in_addr_t, NativeIpAddress );
+		IPMSG_PROPERTY( in_addr_t, NativeNetMask );
+		IPMSG_PROPERTY( in_addr_t, NativeNetworkAddress );
+		IPMSG_PROPERTY( in_addr_t, NativeBroadcastAddress );
 		IPMSG_PROPERTY( int, PortNo );
 };
 
+/**
+ * 롼ץ饹
+ **/
 class GroupItem{
 	public:
 		IPMSG_PROPERTY( string, GroupName );
 		IPMSG_PROPERTY( string, EncodingName );
 };
 
+/**
+ * ۥȥ饹
+ **/
 class HostListItem{
 	public:
 		IPMSG_PROPERTY( string, Version );
@@ -114,67 +140,111 @@ class HostListItem{
 		IPMSG_PROPERTY( unsigned long, EncryptionCapacity );
 		IPMSG_PROPERTY( string, PubKeyHex );
 		IPMSG_PROPERTY( string, EncryptMethodHex );
-		bool IsLocalHost();
-		bool IsFileAttachSupport();
-		bool IsEncryptSupport();
-		bool IsAbsence();
-		bool Equals( HostListItem item );
-		int Compare( HostListItem item );
+		bool IsLocalHost() const;
+		bool IsFileAttachSupport() const;
+		bool IsEncryptSupport() const;
+		bool IsAbsence() const;
+		bool Equals( const HostListItem& item ) const;
+		int Compare( const HostListItem& item ) const;
 		void QueryVersionInfo();
 		void QueryAbsenceInfo();
 };
 
+/**
+ * ۥȰӥ饹
+ *ʳApplicationɬפ˱ƤΥ饹ѾƽƤ
+ **/
 class HostListComparator{
 	public:
+		/**
+		 * ӡ
+		 * @param host1 ۥȾ1
+		 * @param host2 ۥȾ2
+		 * @retval -n:host1礭
+		 * @retval 0:host1host2
+		 * @retval +n:host2礭
+		 */
 		virtual int compare( vector<HostListItem>::iterator host1, vector<HostListItem>::iterator host2 )=0;
 };
 
+/**
+ * ۥȰǥեȥӥ饹
+ **/
 class HostListDefaultComparator: public HostListComparator{
 	public:
+		/**
+		 * ӡ
+		 * @param host1 ۥȾ1
+		 * @param host2 ۥȾ2
+		 * @retval -n:host1礭
+		 * @retval 0:host1host2
+		 * @retval +n:host2礭
+		 */
 		virtual int compare( vector<HostListItem>::iterator host1, vector<HostListItem>::iterator host2 ){
 			return host1->Compare( *host2 );
 		};
 };
 
+/**
+ * ۥȰ饹
+ **/
 class HostList{
 	public:
 		IPMSG_PROPERTY( bool, IsAsking );
 		IPMSG_PROPERTY( time_t, AskStartTime );
 		IPMSG_PROPERTY( time_t, PrevTry );
 		IPMSG_PROPERTY( int, RetryCount );
-		void AddHost( HostListItem host );
+		void AddHost( const HostListItem& host );
 		void Delete( vector<HostListItem>::iterator &it );
 		void DeleteHost( string hostname );
 		vector<HostListItem>::iterator FindHostByAddress( string addr );
 		vector<HostListItem>::iterator FindHostByHostName( string hostName );
-		static HostListItem CreateHostListItemFromPacket( Packet packet );
-		vector<HostListItem>::iterator begin(){ return items.begin(); };
-		vector<HostListItem>::iterator end(){ return items.end(); };
-		int size(){ return items.size(); };
-		void clear(){ return items.clear(); };
-		string ToString( int start );
+		static HostListItem CreateHostListItemFromPacket( const Packet& packet );
+		vector<HostListItem>::iterator begin();
+		vector<HostListItem>::iterator end();
+		int size() const;
+		void clear();
+		string ToString( int start, const struct sockaddr_in *addr );
 		void sort( HostListComparator *comparator );
+		HostList();
+		HostList( const HostList& other );
+		~HostList();
+		HostList& operator=( const HostList& other );
 	private:
 		void qsort( HostListComparator *comparator, int left, int right );
+		void Lock( const char *pos ) const;
+		void Unlock( const char *pos ) const;
+		void CopyFrom( const HostList& other );
 		vector<HostListItem>items;
+		pthread_mutex_t hostListMutex;
 };
 
+/**
+ * ե̾С饹
+ * ʳApplicationɬפ˱ƤΥ饹ѾƽƤ
+ **/
 class FileNameConverter {
 	public:
 		virtual string ConvertNetworkToLocal( string original_file_name ) = 0;
 		virtual string ConvertLocalToNetwork( string original_file_name ) = 0;
 };
 
+/**
+ * ե̵̾ѴС饹
+ **/
 class NullFileNameConverter:public FileNameConverter {
 	public:
 		virtual string ConvertNetworkToLocal( string original_file_name ){ return original_file_name; };
 		virtual string ConvertLocalToNetwork( string original_file_name ){ return original_file_name; };
 };
 
+/**
+ * źեե륯饹
+ **/
 class AttachFile{
 	public:
-		map<string, vector<unsigned long> >::iterator beginExtAttrs(){ return _ExtAttrs.begin(); };
-		map<string, vector<unsigned long> >::iterator endExtAttrs(){ return _ExtAttrs.end(); };
+		map<string, vector<unsigned long> >::iterator beginExtAttrs() { return _ExtAttrs.begin(); };
+		map<string, vector<unsigned long> >::iterator endExtAttrs() { return _ExtAttrs.end(); };
 		void addExtAttrs( string key, unsigned long val ){ _ExtAttrs[key].push_back( val ); };
 		IPMSG_PROPERTY( int, FileId );
 		IPMSG_PROPERTY( string, FullPath );
@@ -188,22 +258,19 @@ class AttachFile{
 		IPMSG_PROPERTY( unsigned long, Attr );
 
 		AttachFile();
-		bool IsRegularFile();
-		bool IsDirectory();
+		bool IsRegularFile() const;
+		bool IsDirectory() const;
 		void GetLocalFileInfo();
 	private:
 		map<string, vector<unsigned long> > _ExtAttrs;
 	public:
 		static AttachFile AnalyzeHeader( char *buf, FileNameConverter *conv );
-		static string CreateDirFullPath( vector<string> dirstack );
+		static string CreateDirFullPath( const vector<string>& dirstack );
 };
 
-#define IPMSG_SIZE_B	(long double)(1)
-#define IPMSG_SIZE_KB	(long double)(1024 * IPMSG_SIZE_B)
-#define IPMSG_SIZE_MB	(long double)(1024 * IPMSG_SIZE_KB)
-#define IPMSG_SIZE_GB	(long double)(1024 * IPMSG_SIZE_MB)
-#define IPMSG_SIZE_TB	(long double)(1024 * IPMSG_SIZE_GB)
-
+/**
+ * ɾ󥯥饹
+ **/
 class DownloadInfo{
 	public:
 		IPMSG_PROPERTY( unsigned long long, Size );
@@ -214,50 +281,43 @@ class DownloadInfo{
 		IPMSG_PROPERTY_REF( AttachFile, File );
 
 		DownloadInfo():_Size( 0ULL ), _Time( 0 ), _FileCount( 0L ), _LocalFileName(""){};
-		long double getSpeed(){ return Time() == 0 ? (long double)0 : ( ( long double )Size() / ( long double )Time() ); };
-		string getSpeedString() { return DownloadInfo::getUnitSizeString( ( long long )getSpeed() ) + "/sec"; };
-		string getSizeString() { return DownloadInfo::getUnitSizeString( Size() ); };
-		static string getUnitSizeString( long long size )
-		{
-			long double dsize = (long double)size;
-			char buf[100];
-			if ( dsize >= IPMSG_SIZE_TB ) {
-				snprintf( buf, sizeof( buf ), "%.2Lf TB", (dsize / IPMSG_SIZE_TB) );
-				return buf;
-			} else if ( dsize >= IPMSG_SIZE_GB ) {
-				snprintf( buf, sizeof( buf ), "%.2Lf GB", (dsize / IPMSG_SIZE_GB) );
-				return buf;
-			} else if ( dsize >= IPMSG_SIZE_MB ) {
-				snprintf( buf, sizeof( buf ), "%.2Lf MB", (dsize / IPMSG_SIZE_MB) );
-				return buf;
-			} else if ( dsize >= IPMSG_SIZE_KB ) {
-				snprintf( buf, sizeof( buf ), "%.2Lf KB", (dsize / IPMSG_SIZE_KB) );
-				return buf;
-			}
-			snprintf( buf, sizeof( buf ), "%lld B", size );
-			return buf;
-		};
+		long double getSpeed();
+		string getSpeedString();
+		string getSizeString();
+		static string getUnitSizeString( long long size );
 };
 
+/**
+ * źեե饹
+ **/
 class AttachFileList{
 	public:
-		inline void AddFile( AttachFile& file ){
-			files.push_back( file );
-		};
-		vector<AttachFile>::iterator begin() { return files.begin(); };
-		vector<AttachFile>::iterator end() { return files.end(); };
-		int size() { return files.size(); };
-		void clear() { return files.clear(); };
-		vector<AttachFile>::iterator erase( vector<AttachFile>::iterator item ) { return files.erase( item ); };
-		vector<AttachFile>::iterator erase( AttachFile &item ) { return erase( FindByFileId( item.FileId() ) ); };
-		vector<AttachFile>::iterator FindByFullPath( string fullPath );
+		void AddFile( const AttachFile& file );
+		vector<AttachFile>::iterator begin();
+		vector<AttachFile>::iterator end();
+		int size() const;
+		void clear();
+		vector<AttachFile>::iterator erase( vector<AttachFile>::iterator item );
+		vector<AttachFile>::iterator erase( const AttachFile& item );
+		vector<AttachFile>::iterator FindByFullPath( const string& fullPath );
 		vector<AttachFile>::iterator FindByFileId( int file_id );
+		AttachFileList();
+		AttachFileList( const AttachFileList& other );
+		~AttachFileList();
+		AttachFileList& operator=( const AttachFileList& other );
 	private:
+		void Lock( const char *pos ) const;
+		void Unlock( const char *pos ) const;
+		void CopyFrom( const AttachFileList& other );
 		vector<AttachFile> files;
+		pthread_mutex_t filesMutex;
 };
 
 class IpMessengerEvent;
 
+/**
+ * å饹
+ **/
 class RecievedMessage{
 	public:
 		IPMSG_PROPERTY( Packet, MessagePacket );
@@ -265,6 +325,7 @@ class RecievedMessage{
 		IPMSG_PROPERTY( time_t, Recieved );
 		IPMSG_PROPERTY( bool, IsConfirmed );
 		IPMSG_PROPERTY( bool, IsSecret );
+		IPMSG_PROPERTY( bool, IsNoLogging );
 		IPMSG_PROPERTY( bool, IsCrypted );
 		IPMSG_PROPERTY( HostListItem, Host );
 		IPMSG_PROPERTY( bool, IsPasswordLock );
@@ -272,27 +333,45 @@ class RecievedMessage{
 		IPMSG_PROPERTY( bool, IsMulticast );
 		IPMSG_PROPERTY( bool, HasAttachFile );
 		IPMSG_PROPERTY_REF( AttachFileList, Files );
+		RecievedMessage();
+		RecievedMessage( const RecievedMessage& other );
+		RecievedMessage& operator=( const RecievedMessage& other );
 		bool DownloadFile( AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
 		bool DownloadDir( AttachFile &file, string saveDirName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
 	private:
+		void CopyFrom( const RecievedMessage& other );
 		bool DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
 		bool DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, string saveDirName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv=NULL, void *data=NULL );
 		string GetFormalDir( string dirName );
 		string GetSaveDir( string saveName, string saveBaseDir );
 };
 
+/**
+ * å饹
+ **/
 class RecievedMessageList {
 	public:
-		vector<RecievedMessage>::iterator begin(){ return messages.begin(); };
-		vector<RecievedMessage>::iterator end(){ return messages.end(); };
-		vector<RecievedMessage>::iterator erase( vector<RecievedMessage>::iterator item ){ return messages.erase( item ); };
-		void append( RecievedMessage item ){ messages.push_back( item ); };
-		int size(){ return messages.size(); };
-		void clear(){ return messages.clear(); };
+		vector<RecievedMessage>::iterator begin();
+		vector<RecievedMessage>::iterator end();
+		vector<RecievedMessage>::iterator erase( vector<RecievedMessage>::iterator item );
+		void append( const RecievedMessage &item );
+		int size() const;
+		void clear();
+		RecievedMessageList();
+		RecievedMessageList( const RecievedMessageList& other );
+		~RecievedMessageList();
+		RecievedMessageList& operator=( const RecievedMessageList& other );
 	private:
+		void Lock( const char *pos ) const;
+		void Unlock( const char *pos ) const;
+		void CopyFrom( const RecievedMessageList& other );
 		vector<RecievedMessage> messages;
+		pthread_mutex_t messagesMutex;
 };
 
+/**
+ * å饹
+ **/
 class SentMessage{
 	public:
 		IPMSG_PROPERTY( struct sockaddr_in, To );
@@ -309,29 +388,50 @@ class SentMessage{
 		IPMSG_PROPERTY( bool, IsConfirmed );
 		IPMSG_PROPERTY( bool, IsConfirmAnswered );
 		IPMSG_PROPERTY( bool, IsSecret );
+		IPMSG_PROPERTY( bool, IsNoLogging );
 		IPMSG_PROPERTY( int, HostCountAtSameTime );
 		IPMSG_PROPERTY( unsigned long, Opt );
 		IPMSG_PROPERTY_REF( AttachFileList, Files );
-		bool isRetryMaxOver();
-		bool needSendRetry( time_t tryNow );
-		vector<AttachFile>::iterator FindAttachFileByPacket( Packet packet );
+		SentMessage();
+		SentMessage( const SentMessage& other );
+		SentMessage& operator=( const SentMessage& other );
+		bool isRetryMaxOver() const;
+		bool needSendRetry( time_t tryNow ) const;
+		vector<AttachFile>::iterator FindAttachFileByPacket( const Packet &packet );
+	private:
+		void CopyFrom( const SentMessage& other );
 };
 
+/**
+ * å饹
+ **/
 class SentMessageList {
 	public:
-		vector<SentMessage>::iterator begin(){ return messages.begin(); };
-		vector<SentMessage>::iterator end(){ return messages.end(); };
-		vector<SentMessage>::iterator erase( vector<SentMessage>::iterator item ){ return messages.erase( item ); };
+		vector<SentMessage>::iterator begin();
+		vector<SentMessage>::iterator end();
+		vector<SentMessage>::iterator erase( vector<SentMessage>::iterator item );
 		vector<SentMessage>::iterator FindSentMessageByPacketNo( unsigned long PacketNo );
 		vector<SentMessage>::iterator FindSentMessageByPacket( Packet packet );
-		void append( SentMessage item ){ messages.push_back( item ); };
-		int size(){ return messages.size(); };
-		void clear(){ return messages.clear(); };
-		vector<SentMessage> *GetMessageList(){ return &messages; };
+		void append( const SentMessage &item );
+		int size() const;
+		void clear();
+		vector<SentMessage> *GetMessageList();
+		SentMessageList();
+		SentMessageList( const SentMessageList& other );
+		~SentMessageList();
+		SentMessageList& operator=( const SentMessageList& other );
+
 	private:
+		void Lock( const char *pos ) const;
+		void Unlock( const char *pos ) const;
+		void CopyFrom( const SentMessageList& other );
 		vector<SentMessage> messages;
+		pthread_mutex_t messagesMutex;
 };
 
+/**
+ * Ժߥ⡼ɥ饹
+ **/
 class AbsenceMode {
 	public:
 		IPMSG_PROPERTY( string, EncodingName );
@@ -341,48 +441,117 @@ class AbsenceMode {
 
 
 /**
- * IP Messenger ٥ȥ֥
- * ʳApplicationϤΥ֥ȤѾƽƤ
+ * IP Messenger ٥ȥ饹
+ * ʳApplicationϤΥ饹ѾƽƤ
  **/
 class IpMessengerEvent {
 	public:
-		//ۥȥꥹȹ
+		/**
+		 * ۥȥꥹȹ奤٥
+		 * @param hostList ۥȥꥹ
+		 */
 		virtual void UpdateHostListAfter( HostList& hostList )=0;
-		//ۥȥꥹȼȥ饤顼
+		/**
+		 * ۥȥꥹȼȥ饤顼٥
+		 * @retval true:ȥ饤
+		 * @retval false:ȥ饤ʤ
+		 */
 		virtual bool GetHostListRetryError()=0;
-		//å(ƥå¸פʤTRUE֤)
+		/**
+		 * å奤٥ȡ
+		 * @param msg å
+		 * @retval true:ƥå¸
+		 * @retval false:å¸
+		 */
 		virtual bool RecieveAfter( RecievedMessage& msg )=0;
-		//å
+		/**
+		 * å奤٥
+		 * @param msg å
+		 */
 		virtual void SendAfter( SentMessage& msg )=0;
-		//åȥ饤顼
+		/**
+		 * åȥ饤顼٥
+		 * @param msg å
+		 * @retval true:ȥ饤
+		 * @retval false:ȥ饤ʤ
+		 */
 		virtual bool SendRetryError( SentMessage& msg )=0;
-		//θ
+		/**
+		 * θ奤٥
+		 * @param msg å
+		 */
 		virtual void OpenAfter( SentMessage& msg )=0;
-		//ɳ
+		/**
+		 * ɳϥ٥
+		 * @param msg å
+		 * @param file źեե
+		 * @param info ɾ
+		 * @param data DownloadFileDownloadDirǻꤷǤեǡؤΥݥ
+		 */
 		virtual void DownloadStart( RecievedMessage& msg, AttachFile& file, DownloadInfo &info, void *data )=0;
-		//ɽ
+		/**
+		 * ɽ楤٥
+		 * @param msg å
+		 * @param file źեե
+		 * @param info ɾ
+		 * @param data DownloadFileDownloadDirǻꤷǤեǡؤΥݥ
+		 */
 		virtual void DownloadProcessing( RecievedMessage& msg, AttachFile& file, DownloadInfo &info, void *data )=0;
-		//ɽλ
+		/**
+		 * ɽλ٥
+		 * @param msg å
+		 * @param file źեե
+		 * @param info ɾ
+		 * @param data DownloadFileDownloadDirǻꤷǤեǡؤΥݥ
+		 */
 		virtual void DownloadEnd( RecievedMessage& msg, AttachFile& file, DownloadInfo &info, void *data )=0;
-		//ɥ顼(ȥ饤TRUE֤)
+		/**
+		 * ɥ顼٥(ȥ饤TRUE֤)
+		 * @param msg å
+		 * @param file źեե
+		 * @param info ɾ
+		 * @param data DownloadFileDownloadDirǻꤷǤեǡؤΥݥ
+		 * @retval true:ȥ饤
+		 * @retval false:ȥ饤ʤ
+		 */
 		virtual bool DownloadError( RecievedMessage& msg, AttachFile& file, DownloadInfo &info, void *data )=0;
-		//ۥȤλθ
+		/**
+		 * ۥȤλθ奤٥
+		 * @param hostList ۥȥꥹ
+		 */
 		virtual void EntryAfter( HostList& hostList )=0;
-		//ۥȤæθ
+		/**
+		 * ۥȤæθ奤٥
+		 * @param hostList ۥȥꥹ
+		 */
 		virtual void ExitAfter( HostList& hostList )=0;
-		//Ժߥ⡼ɹ
+		/**
+		 * Ժߥ⡼ɹ奤٥
+		 * @param hostList ۥȥꥹ
+		 */
 		virtual void AbsenceModeChangeAfter( HostList& hostList )=0;
-		//С
+		/**
+		 * С奤٥
+		 * @param host ۥ
+		 * @param version С
+		 */
 		virtual void VersionInfoRecieveAfter( HostListItem &host, string version )=0;
-		//Ժ߾ܺپ
+		/**
+		 * Ժ߾ܺپ奤٥
+		 * @param host ۥ
+		 * @param absenceDetail Ժ߾ܺپ
+		 */
 		virtual void AbsenceDetailRecieveAfter( HostListItem& host, string absenceDetail )=0;
+		/**
+		 * ǥȥ饯
+		 */
 		virtual ~IpMessengerEvent()=0;
 };
 
 class IpMessengerAgentImpl;
 
 /**
- * IP Messenger 
+ * IP Messenger ȥ饹
  **/
 class IpMessengerAgent {
 	public:
@@ -439,17 +608,17 @@ class IpMessengerAgent {
 		/**
 		 * åź̵
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, bool isLockPassword=false, int hostCountAtSameTime=1, unsigned long opt=0UL );
+		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * åʰźա
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFile file, bool isLockPassword=false, int hostCountAtSameTime=1, unsigned long opt=0UL );
+		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFile& file, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * åʣźա
 		 **/
-		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFileList files, bool isLockPassword=false, int hostCountAtSameTime=1, unsigned long opt=0UL );
+		SentMessage SendMsg( HostListItem host, string msg, bool isSecret, AttachFileList& files, bool isLockPassword=false, int hostCountAtSameTime=1, bool IsNoLogging=false, unsigned long opt=0UL );
 
 		/**
 		 * Ժ߲
@@ -552,7 +721,27 @@ class IpMessengerAgent {
 		bool IsAbsence();
 
 		/**
-		 * ͥåȥκƵư
+		 * ͥåȥεưNIC
+		 **/
+		void StartNetwork( const vector<NetworkInterface>& nics );
+
+		/**
+		 * ͥåȥεư(ǥե)
+		 **/
+		void StartNetwork();
+
+		/**
+		 * ͥåȥνλ
+		 **/
+		void StopNetwork();
+
+		/**
+		 * ͥåȥκƵưNIC
+		 **/
+		void RestartNetwork( const vector<NetworkInterface>& nics );
+
+		/**
+		 * ͥåȥκƵư(ǥե)
 		 **/
 		void RestartNetwork();
 
