@@ -1,4 +1,9 @@
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <IpMessenger.h>
+
 #if defined(DEBUG) || defined(INFO)
 #include <IpMessengerImpl.h>
 #include <ctype.h>
@@ -82,10 +87,15 @@ GetCommandString( unsigned long cmd )
 	return "no match";
 }
 
+/**
+ * ѥåȥ֥Ȥפ롣
+ * @param packet ѥåȥ֥
+ * @param sender_addr IPɥ쥹
+ */
 void
 IpMsgDumpPacket( Packet packet, struct sockaddr_in sender_addr ){
 	printf( ">> R E C V >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");fflush(stdout);
-	char ipaddrbuf[100];
+	char ipaddrbuf[IPV4_ADDR_MAX_SIZE];
 	printf( "send from %s(%d)\n", inet_ntoa_r( sender_addr.sin_addr.s_addr, ipaddrbuf, sizeof( ipaddrbuf ) ), ntohs( sender_addr.sin_port ) );fflush(stdout);
 	printf( "VersionNo    [%ld]\n", packet.VersionNo() );fflush(stdout);
 	printf( "PacketNo     [%ld]\n", packet.PacketNo() );fflush(stdout);
@@ -97,6 +107,11 @@ IpMsgDumpPacket( Packet packet, struct sockaddr_in sender_addr ){
 	printf( "<< R E C V <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n\n");fflush(stdout);
 }
 
+/**
+ * ۥȥꥹȤפ롣
+ * @param s إåեåȥʸ
+ * @param hostList ۥȥꥹȥ֥
+ */
 void
 IpMsgDumpHostList( const char *s, HostList& hostList )
 {
@@ -147,6 +162,10 @@ static int inet_index_2 = 1;
 static int inet_index_3 = 2;
 static int inet_index_4 = 3;
 
+/**
+ * ǥåɥinet_ntoaν
+ * @retval true
+ */
 static bool
 inet_ntoa_init()
 {
@@ -163,6 +182,13 @@ inet_ntoa_init()
 	return true;
 }
 
+/**
+ * ǥåɥinet_ntoa
+ * @param s_addr IPɥ쥹
+ * @param *ret оݤΥХåեɥ쥹
+ * @param size оݤΥХåեΥХȿ
+ * @retval оݤΥХåեɥ쥹(ret)
+ */
 char *
 inet_ntoa_r( in_addr_t s_addr, char *ret, int size )
 {
@@ -175,3 +201,95 @@ inet_ntoa_r( in_addr_t s_addr, char *ret, int size )
 	return ret;
 }
 
+/**
+ * ǥߥ塼ƥå
+ * @param pos ץȤʸ
+ * @param mutex ߥ塼ƥåΥɥ쥹
+ * @param mutexattr ߥ塼ƥå°
+ * @retval pthread_mutex_init
+ */
+int
+IpMsgMutexInit( const char *pos, pthread_mutex_t *mutex, const pthread_mutexattr_t *mutexattr )
+{
+#ifdef HAVE_PTHREAD
+#if defined(LOCK_DEBUG)
+	printf( "MutexInit before:%s\n", pos );fflush(stdout);
+#endif
+	int ret = pthread_mutex_init(mutex, mutexattr);
+#if defined(LOCK_DEBUG)
+	printf( "MutexInit after :%s\n", pos );fflush(stdout);
+#endif
+	return ret;
+#else
+	return 0;
+#endif
+}
+
+/**
+ * ǥߥ塼ƥåå
+ * @param pos ץȤʸ
+ * @param mutex ߥ塼ƥåΥɥ쥹
+ * @retval pthread_mutex_lock
+ */
+int
+IpMsgMutexLock( const char *pos, pthread_mutex_t *mutex )
+{
+#ifdef HAVE_PTHREAD
+#if defined(LOCK_DEBUG)
+	printf( "MutexLock before:%s\n", pos );fflush(stdout);
+#endif
+	int ret = pthread_mutex_lock( mutex );
+#if defined(LOCK_DEBUG)
+	printf( "MutexLock after :%s\n", pos );fflush(stdout);
+#endif
+	return ret;
+#else
+	return 0;
+#endif
+}
+
+/**
+ * ǥߥ塼ƥåå
+ * @param pos ץȤʸ
+ * @param mutex ߥ塼ƥåΥɥ쥹
+ * @retval pthread_mutex_unlock
+ */
+int
+IpMsgMutexUnlock( const char *pos, pthread_mutex_t *mutex )
+{
+#ifdef HAVE_PTHREAD
+#if defined(LOCK_DEBUG)
+	printf( "MutexUnlock before:%s\n", pos );fflush(stdout);
+#endif
+	int ret = pthread_mutex_unlock( mutex );
+#if defined(LOCK_DEBUG)
+	printf( "MutexUnlock after :%s\n", pos );fflush(stdout);
+#endif
+	return ret;
+#else
+	return 0;
+#endif
+}
+
+/**
+ * ǥߥ塼ƥå˴
+ * @param pos ץȤʸ
+ * @param mutex ߥ塼ƥåΥɥ쥹
+ * @retval pthread_mutex_destroy
+ */
+int
+IpMsgMutexDestroy( const char *pos, pthread_mutex_t *mutex )
+{
+#ifdef HAVE_PTHREAD
+#if defined(LOCK_DEBUG)
+	printf( "MutexDestroy before:%s\n", pos );fflush(stdout);
+#endif
+	int ret = pthread_mutex_destroy( mutex );
+#if defined(LOCK_DEBUG)
+	printf( "MutexDestroy after :%s\n", pos );fflush(stdout);
+#endif
+	return ret;
+#else
+	return 0;
+#endif
+}
