@@ -12,10 +12,208 @@
 #include "ipmsg.h"
 using namespace std;
 
+/**
+ * 󥹥ȥ饯
+ */
+RecievedMessage::RecievedMessage(){}
+
+/**
+ * ԡ󥹥ȥ饯
+ * @param other ԡΥ֥
+ */
+RecievedMessage::RecievedMessage( const RecievedMessage& other )
+{
+	CopyFrom( other );
+}
+
+/**
+ * 黻ҡ
+ * @param other ԡΥ֥
+ * @retval 󥹥
+ */
+RecievedMessage&
+RecievedMessage::operator=( const RecievedMessage& other )
+{
+	CopyFrom( other );
+	return *this;
+}
+
+/**
+ * ԡ᥽åɡ
+ * @param other ԡΥ֥
+ */
+void
+RecievedMessage::CopyFrom( const RecievedMessage& other )
+{
+	_MessagePacket = other. _MessagePacket;
+	_Message = other. _Message;
+	_Recieved = other. _Recieved;
+	_IsConfirmed = other. _IsConfirmed;
+	_IsSecret = other. _IsSecret;
+	_IsNoLogging = other. _IsNoLogging;
+	_IsCrypted = other. _IsCrypted;
+	_Host = other. _Host;
+	_IsPasswordLock = other. _IsPasswordLock;
+	_IsBroadcast = other. _IsBroadcast;
+	_IsMulticast = other. _IsMulticast;
+	_HasAttachFile = other. _HasAttachFile;
+	_Files = other._Files;
+}
+
+/**
+ * 󥹥ȥ饯
+ * <ul>
+ * <li>ѥåꥹȤå뤿Υߥ塼ƥå</li>
+ * </ul>
+ */
+RecievedMessageList::RecievedMessageList()
+{
+	IpMsgMutexInit( "RecievedMessageList::RecievedMessageList()", &messagesMutex, NULL );
+}
+
+/**
+ * ԡ󥹥ȥ饯
+ * @param other ԡΥ֥
+ */
+RecievedMessageList::RecievedMessageList( const RecievedMessageList& other )
+{
+	IpMsgMutexInit( "RecievedMessageList::RecievedMessageList(RecievedMessageList&)", &messagesMutex, NULL );
+	Lock( "RecievedMessageList::RecievedMessageList(RecievedMessageList&)" );
+	CopyFrom( other );
+	Unlock( "RecievedMessageList::RecievedMessageList(RecievedMessageList&)" );
+}
+
+/**
+ * ǥȥ饯
+ * <ul>
+ * <li>ѥåꥹȤå뤿Υߥ塼ƥå˴</li>
+ * </ul>
+ */
+RecievedMessageList::~RecievedMessageList()
+{
+	IpMsgMutexDestroy( "RecievedMessageList::~RecievedMessageList()", &messagesMutex );
+}
+
+/**
+ * 黻ҡ
+ * @param other ԡΥ֥
+ * @retval 󥹥
+ */
+RecievedMessageList&
+RecievedMessageList::operator=( const RecievedMessageList& other )
+{
+	IpMsgMutexInit( "RecievedMessageList::operator=(RecievedMessageList&)", &messagesMutex, NULL );
+	Lock( "RecievedMessageList::operator=(RecievedMessageList&)" );
+	CopyFrom( other );
+	Unlock( "RecievedMessageList::operator=(RecievedMessageList&)" );
+	return *this;
+}
+
+/**
+ * ԡ᥽åɡ
+ * @param other ԡΥ֥
+ */
+void
+RecievedMessageList::CopyFrom( const RecievedMessageList& other )
+{
+	messages = other.messages;
+}
+
+/**
+ * åꥹȤå
+ * @param pos åƤ֤򼨤ʸ
+ */
+void
+RecievedMessageList::Lock( const char *pos ) const
+{
+	IpMsgMutexLock( pos, const_cast< pthread_mutex_t* >( &messagesMutex ) );
+}
+
+/**
+ * åꥹȤ򥢥å
+ * @param pos åƤ֤򼨤ʸ
+ */
+void
+RecievedMessageList::Unlock( const char *pos ) const
+{
+	IpMsgMutexUnlock( pos, const_cast< pthread_mutex_t * >( &messagesMutex ) );
+}
+
+/**
+ * ѥåꥹȤƬ򼨤ƥ졼֤
+ * @retval ѥåꥹȤƬ򼨤ƥ졼
+ */
+vector<RecievedMessage>::iterator
+RecievedMessageList::begin()
+{
+	return messages.begin();
+}
+
+/**
+ * ѥåꥹȤܣ򼨤ƥ졼֤
+ * @retval ѥåꥹȤܣ򼨤ƥ졼
+ */
+vector<RecievedMessage>::iterator
+RecievedMessageList::end()
+{
+	return messages.end();
+}
+
+/**
+ * ꤵ줿ƥ졼ǼѥåѥåꥹȤ롣
+ * @param item оݤμѥå򼨤ƥ졼
+ * @retval 줿ѥåμǤ򼨤ƥ졼
+ */
+vector<RecievedMessage>::iterator
+RecievedMessageList::erase( vector<RecievedMessage>::iterator item )
+{
+	Lock( "RecievedMessageList::erase()" );
+	vector<RecievedMessage>::iterator ret = messages.erase( item );
+	Unlock( "RecievedMessageList::erase()" );
+	return ret;
+}
+
+/**
+ * ѥåꥹȤ˥åɲä롣
+ * @param item ѥå
+ */
+void
+RecievedMessageList::append( const RecievedMessage &item )
+{
+	Lock( "RecievedMessageList::append()" );
+	messages.push_back( item );
+	Unlock( "RecievedMessageList::append()" );
+}
+
+/**
+ * ѥåꥹȤθĿ֤
+ * @retval ѥåꥹȤθĿ
+ */
+int
+RecievedMessageList::size() const
+{
+	Lock( "RecievedMessageList::size()" );
+	int ret = messages.size();
+	Unlock( "RecievedMessageList::size()" );
+	return ret;
+}
+
+/**
+ * ѥåꥹȤ򥯥ꥢ롣
+ */
+void
+RecievedMessageList::clear()
+{
+	Lock( "RecievedMessageList::clear()" );
+	messages.clear();
+	Unlock( "RecievedMessageList::clear()" );
+}
+
 /**
  * ե
- * Ф˥ե׵ѥåȤե롣
- * Υ᥽åɤϥåɥդǤʤ
+ * <ul>
+ * <li>Ф˥ե׵ѥåȤե롣</li>
+ * </ul>
  */
 bool
 RecievedMessage::DownloadFile( AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
@@ -56,8 +254,9 @@ RecievedMessage::DownloadFile( AttachFile &file, string saveFileNameFullPath, Do
 
 /**
  * ե
- * Ф˥ե׵ѥåȤե롣
- * Υ᥽åɤϥåɥդǤʤ
+ * <ul>
+ * <li>Ф˥ե׵ѥåȤե롣</li>
+ * </ul>
  */
 bool
 RecievedMessage::DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file, string saveFileNameFullPath, DownloadInfo& info, FileNameConverter *conv, void *data )
@@ -67,7 +266,7 @@ RecievedMessage::DownloadFilePrivate( IpMessengerEvent *event, AttachFile &file,
 
 	svr_addr = MessagePacket().Addr();
 #if defined(DEBUG)
-char ipaddrbuf[100];
+char ipaddrbuf[IPV4_ADDR_MAX_SIZE];
 printf("IP[%s]\n", inet_ntoa_r( svr_addr.sin_addr.s_addr, ipaddrbuf, sizeof( ipaddrbuf ) ) );fflush(stdout);
 printf("saveFileNameFullPath[%s]\n", saveFileNameFullPath.c_str() );fflush(stdout);
 #endif
@@ -165,8 +364,9 @@ printf("saveFileNameFullPath[%s]\n", saveFileNameFullPath.c_str() );fflush(stdou
 
 /**
  * ǥ쥯ȥʥե̾Сץդˡ
- * Ф˥ǥ쥯ȥ׵ѥåȤǥ쥯ȥ롣
- * Υ᥽åɤϥåɥդǤʤ
+ * <ul>
+ * <li>Ф˥ǥ쥯ȥ׵ѥåȤǥ쥯ȥ롣</li>
+ * </ul>
  */
 bool
 RecievedMessage::DownloadDir( AttachFile &file, string saveName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
@@ -205,6 +405,11 @@ RecievedMessage::DownloadDir( AttachFile &file, string saveName, string saveBase
 	return ret;
 }
 
+/**
+ * 줿ǥ쥯ȥ̾롣
+ * @param dirName Υǥ쥯ȥ̾
+ * @retval Υǥ쥯ȥ̾
+ */
 string
 RecievedMessage::GetFormalDir( string dirName )
 {
@@ -214,6 +419,16 @@ RecievedMessage::GetFormalDir( string dirName )
 	return dirName;
 }
 
+/**
+ * ¸ե̾ʤޤϥǥ쥯ȥ̾ˤ롣
+ * <ul>
+ * <li>¸Υǥ쥯ȥꡢեʤޤϥǥ쥯ȥ̾
+ * ʤϥץȥ塢ե̾ΤߤǤ١ˤȤ߹碌ƥեѥ롣</li>
+ * </ul>
+ * @param saveName ¸եʤޤϥǥ쥯ȥ̾̾
+ * @param saveBaseDir ¸ǥ쥯ȥ̾
+ * @retval ¸եʤޤϥǥ쥯ȥ̾
+ */
 string
 RecievedMessage::GetSaveDir( string saveName, string saveBaseDir )
 {
@@ -222,8 +437,9 @@ RecievedMessage::GetSaveDir( string saveName, string saveBaseDir )
 
 /**
  * ǥ쥯ȥʥե̾Сץդˡ
- * Ф˥ǥ쥯ȥ׵ѥåȤǥ쥯ȥ롣
- * Υ᥽åɤϥåɥդǤʤ
+ * <ul>
+ * <li>Ф˥ǥ쥯ȥ׵ѥåȤǥ쥯ȥ롣</li>
+ * </ul>
  */
 bool
 RecievedMessage::DownloadDirPrivate( IpMessengerEvent *event, AttachFile &file, string saveName, string saveBaseDir, DownloadInfo& info, FileNameConverter *conv, void *data )
@@ -262,9 +478,6 @@ printf("saveBaseDirFormal[%s]\n", saveBaseDirFormal.c_str() );fflush(stdout);
 	struct sockaddr_in svr_addr;
 	int sock = socket( AF_INET, SOCK_STREAM, 0 );
 
-	svr_addr.sin_family = AF_INET;
-	svr_addr.sin_port = IPMSG_DEFAULT_PORT;
-	svr_addr.sin_addr = MessagePacket().Addr().sin_addr;
 	svr_addr = MessagePacket().Addr();
 	if ( connect( sock, (struct sockaddr *)&svr_addr, sizeof( svr_addr ) ) != 0 ){
 		perror("connect");
